@@ -135,7 +135,7 @@ class Invoice(models.Model):
     sent = models.BooleanField(_("Sent"), help_text=_('Invoice sent?'))
     charged = models.BooleanField(_("Charged"), help_text=_('Invoice charged?'))
     taxes = models.ForeignKey(Tax, related_name="taxes")
-    retentions = models.ForeignKey(Retention, related_name="retentions", default='')
+    retentions = models.ForeignKey(Retention, related_name="retentions", default='1', blank=True)
     currency = models.ForeignKey(Currency, related_name="currency")
     date = models.DateTimeField(_('Creation date'))
     invoice_number = models.IntegerField(_('Invoice Number'))
